@@ -6,12 +6,13 @@ Module: Function/Start
 # General Python modules
 import numpy as np
 import os
+import datetime
 import glob
 import pandas as pd
 from osgeo import gdal
 import calendar
 
-def Nearest_Interpolate(Dir_in, Startdate, Enddate, Dir_out = None):
+def Nearest_Interpolate(Dir_in, Startdate, Enddate, format_in = None, format_out = None, Dir_out = None, AOI = None):
     """
     This functions calculates monthly tiff files based on the 16 daily tiff files. (will calculate the average)
 
@@ -35,20 +36,30 @@ def Nearest_Interpolate(Dir_in, Startdate, Enddate, Dir_out = None):
     os.chdir(Dir_in)
 
     # Find all eight daily files
-    files = glob.glob('*16-daily*.tif')
-
+    if format_in == None:
+        files = glob.glob('*16-daily*.tif')
+    else:
+        files = glob.glob(format_in.replace(":02d","").format(yyyy= "*", mm = "*", dd = "*"))    
+        
     # Create array with filename and keys (DOY and year) of all the 8 daily files
     i = 0
     DOY_Year = np.zeros([len(files),3])
     for File in files:
 
-        # Get the time characteristics from the filename
-        year = File.split('.')[-4][-4:]
-        month = File.split('.')[-3]
-        day = File.split('.')[-2]
+        if format_in == None:
+            # Get the time characteristics from the filename
+            year = int(File.split('.')[-4][-4:])
+            month = int(File.split('.')[-3])
+            day = int(File.split('.')[-2])
+        else:
+            Date = datetime.datetime.strptime(File, format_in.replace("{yyyy}", "%Y").replace("{mm:02d}", "%m").replace("{dd:02d}", "%d"))        
+            year = Date.year
+            month = Date.month
+            day = Date.day
+
 
         # Create pandas Timestamp
-        date_file = '%s-%02s-%02s' %(year, month, day)
+        date_file = '%d-%02d-%02d' %(year, month, day)
         Datum = pd.Timestamp(date_file)
 
         # Get day of year
@@ -146,9 +157,16 @@ def Nearest_Interpolate(Dir_in, Startdate, Enddate, Dir_out = None):
         if Dir_out == None:
             Dir_out = Dir_in
 
-        # Define output name
-        output_name = os.path.join(Dir_out, files[int(row)].replace('16-daily', 'monthly'))
-        output_name = output_name[:-9] + '%02d.01.tif' %(date.month)
+       # Define output name
+        if format_out == None:
+            output_name = os.path.join(Dir_out, files[int(row)].replace('16-daily', 'monthly'))
+            output_name = output_name[:-9] + '%02d.01.tif' %(date.month)
+        else:
+            output_name = os.path.join(Dir_out, format_out.format(yyyy = date.year,  mm = date.month, dd = 1))       
+
+        if str(type(AOI)) == "<class 'numpy.ndarray'>":
+            Data_one_month = Data_one_month * AOI
+
 
         # Save tiff file
         DC.Save_as_tiff(output_name, Data_one_month, geo_out, proj)
