@@ -7,12 +7,12 @@ Created on Thu Oct 22 14:44:51 2020
 import matplotlib.pyplot as plt
 import numpy as np
 
-def Show_array(Array):
+def Show_array(Array, bins = 'auto'):
     
     rng = Array.flatten()
     rng[rng==-9999] = np.nan
     rng = rng[~np.isnan(rng)]
-    plt.hist(rng, bins='auto')  # arguments are passed to np.histogram
-    plt.title("Histogram with 'auto' bins")
+    plt.hist(rng, bins=bins)  # arguments are passed to np.histogram
+    plt.title("Histogram with  %s bins" %bins)
     plt.show()
     return()
\ No newline at end of file
