@@ -403,7 +403,10 @@ def clip_data(input_file, latlim, lonlim, epsg_clip = 4326, band = 1):
     # Open Array
     data_in = dest_in.GetRasterBand(band).ReadAsArray()
     Proj_out = Get_epsg(dest_in)
-    
+ 
+    lonlim_rep = np.copy(lonlim)
+    latlim_rep = np.copy(latlim)  
+ 
     if Proj_out != epsg_clip:
      
         inProj = Proj(init='epsg:%d' %epsg_clip)
@@ -411,17 +414,18 @@ def clip_data(input_file, latlim, lonlim, epsg_clip = 4326, band = 1):
     
         # Up to here, all  the projection have been defined, as well as a
         # transformation from the from to the to
-        lonlim[0], latlim[0] = transform(inProj,outProj,lonlim[0], latlim[0])
-        lonlim[1], latlim[1] = transform(inProj,outProj,lonlim[1], latlim[1])       
+        lonlim_rep[0], latlim_rep[0] = transform(inProj,outProj,lonlim[0], latlim[0])
+        lonlim_rep[1], latlim_rep[1] = transform(inProj,outProj,lonlim[1], latlim[1])       
+ 
 
     # Define the array that must remain
     Geo_in = dest_in.GetGeoTransform()
     Geo_in = list(Geo_in)
-    Start_x = np.max([int(np.floor(np.round((lonlim[0]) - Geo_in[0],5)/ Geo_in[1])),0])
-    End_x = np.min([int(np.ceil(np.round((lonlim[1]) - Geo_in[0], 5)/ Geo_in[1])),int(dest_in.RasterXSize)])
+    Start_x = np.max([int(np.floor(np.round((lonlim_rep[0]) - Geo_in[0],5)/ Geo_in[1])),0])
+    End_x = np.min([int(np.ceil(np.round((lonlim_rep[1]) - Geo_in[0], 5)/ Geo_in[1])),int(dest_in.RasterXSize)])
 
-    Start_y = np.max([int(np.floor(np.round(Geo_in[3] - latlim[1],5)/ -Geo_in[5])),0])
-    End_y = np.min([int(np.ceil(np.round((latlim[0]) - Geo_in[3],5)/Geo_in[5])), int(dest_in.RasterYSize)])
+    Start_y = np.max([int(np.floor(np.round(Geo_in[3] - latlim_rep[1],5)/ -Geo_in[5])),0])
+    End_y = np.min([int(np.ceil(np.round((latlim_rep[0]) - Geo_in[3],5)/Geo_in[5])), int(dest_in.RasterYSize)])
 
     #Create new GeoTransform
     Geo_in[0] = Geo_in[0] + Start_x * Geo_in[1]
